IO API — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# IO API

This section decribes the input and output of PyProcar. This handles the parsing of the density functional codes

PyProcar has the following parsers

- `pyprocar.io.qe.QEParser` is used to parse Quantum Espresso results.

- `pyprocar.io.bxsf.BxsfParser` is used to parse Bxsf formatted results.

- `pyprocar.io.lobster.LobsterParser` is used to parse Lobster results.

- `pyprocar.io.siesta.SiestaParser` is used to parse Siesta results.

- `pyprocar.io.vasp` This module is used to parse Vasp results

- `pyprocar.io.abinit` This module is used to parse Abinit results

- AbinitParser
  - pyprocar.io.abinit.AbinitProcar
  - pyprocar.io.abinit.Output
  - pyprocar.io.abinit.AbinitKpoints
- BxsfParser
  - pyprocar.io.bxsf.BxsfParser
- LobsterParser
  - pyprocar.io.lobster.LobsterParser
- QEParser
  - pyprocar.io.qe.QEParser
- SiestaParser
  - pyprocar.io.siesta.SiestaParser
- VaspParser
  - pyprocar.io.vasp.Outcar
  - pyprocar.io.vasp.Poscar
  - pyprocar.io.vasp.Procar
  - pyprocar.io.vasp.Kpoints
  - pyprocar.io.vasp.VaspXML